/*
 * ftc.h
 *
 * Copyright (c) 2003 Bob Fleck <bob@shmoo.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#ifndef _FTC_H_
#define _FTC_H_

#include <sys/types.h>
#include <sys/endian.h>
#include <sys/time.h>
#include <sys/socket.h>

#include <stdio.h>
#include <signal.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#include <bitstring.h>
#include <errno.h>
#include <assert.h>

#include <ng_hci.h>
#include <ng_l2cap.h>
#include <ng_btsocket.h>

/* Inquiry duration - 15.36s max, 5.12s avg - 9*1.28s=11.52s */
#define FTC_TIMEOUT_INQR         9
#define FTC_MAX_INQR             255

/* How often we do periodic inquiries (mult. by 1.28s) */
#define FTC_PI_MAX               60
#define FTC_PI_MIN               30

/* Reason code to give for rejecting incoming (about to power off is 0x15) */
#define FTC_ERR_REJECT           0x15

#define SIZE(x) (sizeof((x))/sizeof((x)[0]))

/* This variable will cause the scanner to abort gracefully when == 0 */
extern int scanning;

/* prototypes for ftc_util.c */
extern int socket_open(char const *, struct ng_btsocket_hci_raw_filter *);
extern int hci_send(int, char const *, int);
extern int hci_recv_pkt(int, char *, int);
extern int hci_request(int, int, char const *, int);
extern void hci_connect(int, bdaddr_t *);
extern void hci_disconnect(int, int);
extern void hci_reject_con(int, bdaddr_t *);
extern void hci_periodic_inq_start(int, int);
extern void hci_periodic_inq_stop(int);

/* Why is this struct not defined in the ng_  header files? */
struct inquiry_response {
  bdaddr_t	bdaddr;
  u_int8_t	page_scan_rep_mode;
  u_int8_t	page_scan_period_mode;
  u_int8_t	page_scan_mode;
  u_int8_t	class[NG_HCI_CLASS_SIZE];
  u_int16_t	clock_offset;
};

#endif /* _FTC_H_ */
